@@ -38,7 +38,10 @@ def mktorrent(filepath,torrentname,tracker="https://announce.leaguehd.com/announ
         except Exception as r:
             logger.error('删除种子发生错误: %s' %(r))
     logger.info('正在制作种子:'+filepath)
-    order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+changename(filepath)+'\"'+' > /dev/null'
+    if 'win' in sys.platform:
+        order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+changename(filepath)+'\"'+''
+    else:
+        order='mktorrent -v -p -f -l 24 -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+changename(filepath)+'\"'+' > /dev/null'
     #logger.info(order)
     os.system(order)
     logger.info('已完成制作种子'+torrentname)
@@ -81,7 +84,11 @@ def takescreenshot(file,screenshotaddress,screenshotnum):
     firststep=timestep*2
     for i in range (screenshotnum):
         firststep=firststep+timestep
-        screenshotstr='ffmpeg -ss '+str(firststep)+' -i "'+file+'" -f image2 -y "'+os.path.join(screenshotaddress,str(i+1)+'.jpg')+'" &> /dev/null'
+        if 'win' in sys.platform:
+            screenshotstr='ffmpeg -ss '+str(firststep)+' -i "'+file+'" -f image2 -y "'+os.path.join(screenshotaddress,str(i+1)+'.jpg')+'"'
+        else:
+            screenshotstr='ffmpeg -ss '+str(firststep)+' -i "'+file+'" -f image2 -y "'+os.path.join(screenshotaddress,str(i+1)+'.jpg')+'" &> /dev/null'
+        print(screenshotstr)
         os.system(screenshotstr)
     logger.info('截图完毕')
 
